==> dojo-1.9.4.tgz: package/cldr/nls/he/hebrew.js <==
define(
//begin v1.x content
{
	"days-standAlone-short": [
		"א'",
		"ב'",
		"ג'",
		"ד'",
		"ה'",
		"ו'",
		"ש'"
	],
	"months-format-narrow": [
		"תש",
		"חש",
		"כס",
		"טב",
		"שב",
		"אא",
		"אד",
		"ני",
		"אי",
		"סי",
		"תמ",
		"אב",
		"אל"
	],
	"quarters-standAlone-narrow": [
		"ר1",
		"ר2",
		"ר3",
		"ר4"
	],
	"field-weekday": "יום בשבוע",
	"months-standAlone-narrow-leap": "א2",
	"dateFormatItem-GyMMMEd": "E, d MMMM y G",
	"dateFormatItem-MMMEd": "E, d בMMMM",
	"eraNarrow": [
		"לבה״ע"
	],
	"days-format-short": [
		"א'",
		"ב'",
		"ג'",
		"ד'",
		"ה'",
		"ו'",
		"ש'"
	],
	"dateFormat-long": "d בMMMM y",
	"months-format-wide": [
		"תשרי",
		"חשוון",
		"כסלו",
		"טבת",
		"שבט",
		"אדר א׳",
		"אדר",
		"ניסן",
		"אייר",
		"סיון",
		"תמוז",
		"אב",
		"אלול"
	],
	"dateTimeFormat-medium": "{1}, {0}",
	"dayPeriods-format-wide-pm": "אחה״צ",
	"dateFormat-full": "EEEE, d בMMMM y",
	"dateFormatItem-yyyyMEd": "E, d בMMMM y",
	"dateFormatItem-Md": "d בMMMM",
	"field-era": "תקופה",
	"months-standAlone-wide": [
		"תשרי",
		"חשון",
		"כסלו",
		"טבת",
		"שבט",
		"אדר א׳",
		"אדר",
		"ניסן",
		"אייר",
		"סיון",
		"תמוז",
		"אב",
		"אלול"
	],
	"quarters-format-wide": [
		"רבעון 1",
		"רבעון 2",
		"רבעון 3",
		"רבעון 4"
	],
	"field-year": "שנה",
	"dateFormatItem-yyyyMMMM": "MMMM y",
	"field-hour": "שעה",
	"months-format-abbr-leap": "אדר ב׳",
	"months-format-abbr": [
		"תשרי",
		"חשוון",
		"כסלו",
		"טבת",
		"שבט",
		"אדר א׳",
		"אדר",
		"ניסן",
		"אייר",
		"סיון",
		"תמוז",
		"אב",
		"אלול"
	],
	"field-day-relative+0": "היום",
	"field-day-relative+1": "מחר",
	"dateFormatItem-GyMMMd": "d MMMM y G",
	"field-day-relative+2": "מחרתיים",
	"months-standAlone-abbr": [
		"תשרי",
		"חשוון",
		"כסלו",
		"טבת",
		"שבט",
		"אדר א׳",
		"אדר",
		"ניסן",
		"אייר",
		"סיוון",
		"תמוז",
		"אב",
		"אלול"
	],
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-yyyyMMMEd": "E, d בMMMM y",
	"dateFormatItem-M": "MMMM",
	"dateFormatItem-yyyyMMM": "MMMM y",
	"dateFormatItem-yyyyMMMd": "d בMMMM y",
	"dateFormatItem-MMMMd": "d בMMMM",
	"months-standAlone-wide-leap": "אדר ב׳",
	"months-format-narrow-leap": "א2",
	"eraAbbr": [
		"לבה״ע"
	],
	"field-minute": "דקה",
	"field-dayperiod": "לפה״צ/אחה״צ",
	"field-day-relative+-1": "אתמול",
	"field-day-relative+-2": "שלשום",
	"dateFormatItem-MMMd": "d בMMMM",
	"dateFormatItem-MEd": "E, d בMMMM",
	"field-day": "יום",
	"days-format-wide": [
		"יום ראשון",
		"יום שני",
		"יום שלישי",
		"יום רביעי",
		"יום חמישי",
		"יום שישי",
		"יום שבת"
	],
	"field-zone": "אזור",
	"months-standAlone-abbr-leap": "אדר ב׳",
	"dateFormatItem-y": "y G",
	"months-standAlone-narrow": [
		"תש",
		"חש",
		"כס",
		"טב",
		"שב",
		"אא",
		"אד",
		"ני",
		"אי",
		"סי",
		"תמ",
		"אב",
		"אל"
	],
	"field-year-relative+-1": "שנה שעברה",
	"field-month-relative+-1": "חודש שעבר",
	"days-format-abbr": [
		"יום א׳",
		"יום ב׳",
		"יום ג׳",
		"יום ד׳",
		"יום ה׳",
		"יום ו׳",
		"שבת"
	],
	"eraNames": [
		"לבה״ע"
	],
	"days-format-narrow": [
		"א'",
		"ב'",
		"ג'",
		"ד'",
		"ה'",
		"ו׳",
		"ש׳"
	],
	"dateFormatItem-yyyyMd": "d בMMMM y",
	"field-month": "חודש",
	"days-standAlone-narrow": [
		"א׳",
		"ב׳",
		"ג׳",
		"ד׳",
		"ה׳",
		"ו",
		"ש"
	],
	"dateFormatItem-MMM": "MMMM",
	"dayPeriods-format-wide-am": "לפנה״צ",
	"dateFormatItem-MMMMEd": "E, d בMMMM",
	"dateFormat-short": "d בMMMM y",
	"field-second": "שנייה",
	"field-month-relative+0": "החודש",
	"field-month-relative+1": "חודש הבא",
	"dateFormatItem-Ed": "E ה-d",
	"field-week": "שבוע",
	"dateFormat-medium": "d בMMMM y",
	"field-year-relative+0": "השנה",
	"field-week-relative+-1": "שבוע שעבר",
	"dateFormatItem-yyyyM": "MMMM y",
	"field-year-relative+1": "שנה הבאה",
	"dateTimeFormat-short": "{1}, {0}",
	"months-format-wide-leap": "אדר ב׳",
	"dateFormatItem-GyMMM": "MMMM y G",
	"dateFormatItem-yyyy": "y G",
	"field-week-relative+0": "השבוע",
	"field-week-relative+1": "שבוע הבא"
}
//end v1.x content
);

==> dojo-1.13.5.tgz: package/cldr/nls/he/hebrew.js <==
define(
//begin v1.x content
{
	"days-standAlone-short": [
		"א׳",
		"ב׳",
		"ג׳",
		"ד׳",
		"ה׳",
		"ו׳",
		"ש׳"
	],
	"months-format-narrow": [
		"תש׳",
		"חש׳",
		"כס׳",
		"טב׳",
		"שב׳",
		"א״א",
		"אד׳",
		"ני׳",
		"אי׳",
		"סי׳",
		"תמ׳",
		"אב",
		"אל׳"
	],
	"field-second-relative+0": "עכשיו",
	"quarters-standAlone-narrow": [
		"ר1",
		"ר2",
		"ר3",
		"ר4"
	],
	"field-weekday": "יום בשבוע",
	"months-standAlone-narrow-leap": "א״ב",
	"field-wed-relative+0": "יום רביעי",
	"field-wed-relative+1": "יום רביעי הבא",
	"dateFormatItem-GyMMMEd": "E, d MMMM y G",
	"dateFormatItem-MMMEd": "E, d בMMMM",
	"eraNarrow": [
		"לבה״ע"
	],
	"field-tue-relative+-1": "יום שלישי שעבר",
	"days-format-short": [
		"א׳",
		"ב׳",
		"ג׳",
		"ד׳",
		"ה׳",
		"ו׳",
		"ש׳"
	],
	"dateFormat-long": "d בMMMM y",
	"field-fri-relative+-1": "יום שישי שעבר",
	"field-wed-relative+-1": "יום רביעי שעבר",
	"months-format-wide": [
		"תשרי",
		"חשון",
		"כסלו",
		"טבת",
		"שבט",
		"אדר א׳",
		"אדר",
		"ניסן",
		"אייר",
		"סיון",
		"תמוז",
		"אב",
		"אלול"
	],
	"dateTimeFormat-medium": "{1}, {0}",
	"dayPeriods-format-wide-pm": "אחה״צ",
	"dateFormat-full": "EEEE, d בMMMM y",
	"dateFormatItem-yyyyMEd": "E, d בMMMM y",
	"field-thu-relative+-1": "יום חמישי שעבר",
	"dateFormatItem-Md": "d בMMMM",
	"field-era": "תקופה",
	"months-standAlone-wide": [
		"תשרי",
		"חשון",
		"כסלו",
		"טבת",
		"שבט",
		"אדר א׳",
		"אדר",
		"ניסן",
		"אייר",
		"סיון",
		"תמוז",
		"אב",
		"אלול"
	],
	"quarters-format-wide": [
		"רבעון 1",
		"רבעון 2",
		"רבעון 3",
		"רבעון 4"
	],
	"field-year": "שנה",
	"dateFormatItem-yyyyMMMM": "MMMM y",
	"field-hour": "שעה",
	"months-format-abbr-leap": "אדר ב׳",
	"months-format-abbr": [
		"תשרי",
		"חשון",
		"כסלו",
		"טבת",
		"שבט",
		"אדר א׳",
		"אדר",
		"ניסן",
		"אייר",
		"סיון",
		"תמוז",
		"אב",
		"אלול"
	],
	"field-sat-relative+0": "יום שבת",
	"field-sat-relative+1": "יום שבת הבא",
	"field-day-relative+0": "היום",
	"field-thu-relative+0": "יום חמישי",
	"field-day-relative+1": "מחר",
	"field-thu-relative+1": "יום חמישי הבא",
	"dateFormatItem-GyMMMd": "d MMMM y G",
	"field-day-relative+2": "מחרתיים",
	"months-standAlone-abbr": [
		"תשרי",
		"חשוון",
		"כסלו",
		"טבת",
		"שבט",
		"אדר א׳",
		"אדר",
		"ניסן",
		"אייר",
		"סיון",
		"תמוז",
		"אב",
		"אלול"
	],
	"quarters-format-abbr": [
		"רבעון 1",
		"רבעון 2",
		"רבעון 3",
		"רבעון 4"
	],
	"quarters-standAlone-wide": [
		"רבעון 1",
		"רבעון 2",
		"רבעון 3",
		"רבעון 4"
	],
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-yyyyMMMEd": "E, d בMMMM y",
	"dateFormatItem-M": "MMMM",
	"days-standAlone-wide": [
		"יום ראשון",
		"יום שני",
		"יום שלישי",
		"יום רביעי",
		"יום חמישי",
		"יום שישי",
		"יום שבת"
	],
	"dateFormatItem-yyyyMMM": "MMMM y",
	"dateFormatItem-yyyyMMMd": "d בMMMM y",
	"dateFormatItem-MMMMd": "d בMMMM",
	"months-standAlone-wide-leap": "אדר ב׳",
	"field-sun-relative+0": "יום ראשון",
	"field-sun-relative+1": "יום ראשון הבא",
	"quarters-standAlone-abbr": [
		"רבעון 1",
		"רבעון 2",
		"רבעון 3",
		"רבעון 4"
	],
	"months-format-narrow-leap": "א״ב",
	"eraAbbr": [
		"לבה״ע"
	],
	"field-minute": "דקה",
	"field-dayperiod": "לפנה״צ/אחה״צ",
	"field-day-relative+-1": "אתמול",
	"field-day-relative+-2": "שלשום",
	"dateFormatItem-MMMd": "d בMMMM",
	"dateFormatItem-MEd": "E, d בMMMM",
	"field-fri-relative+0": "יום שישי",
	"field-fri-relative+1": "יום שישי הבא",
	"field-day": "יום",
	"days-format-wide": [
		"יום ראשון",
		"יום שני",
		"יום שלישי",
		"יום רביעי",
		"יום חמישי",
		"יום שישי",
		"יום שבת"
	],
	"field-zone": "אזור",
	"months-standAlone-abbr-leap": "אדר ב׳",
	"dateFormatItem-y": "y G",
	"months-standAlone-narrow": [
		"תש׳",
		"חש׳",
		"כס׳",
		"טב׳",
		"שב׳",
		"א״א",
		"אד׳",
		"ני׳",
		"אי׳",
		"סי׳",
		"תמ׳",
		"אב",
		"אל׳"
	],
	"field-year-relative+-1": "השנה שעברה",
	"field-month-relative+-1": "החודש שעבר",
	"days-format-abbr": [
		"יום א׳",
		"יום ב׳",
		"יום ג׳",
		"יום ד׳",
		"יום ה׳",
		"יום ו׳",
		"שבת"
	],
	"eraNames": [
		"לבה״ע"
	],
	"days-format-narrow": [
		"א׳",
		"ב׳",
		"ג׳",
		"ד׳",
		"ה׳",
		"ו׳",
		"ש׳"
	],
	"dateFormatItem-yyyyMd": "d בMMMM y",
	"field-month": "חודש",
	"dateFormatItem-MMM": "MMMM",
	"days-standAlone-narrow": [
		"א׳",
		"ב׳",
		"ג׳",
		"ד׳",
		"ה׳",
		"ו׳",
		"ש׳"
	],
	"field-tue-relative+0": "יום שלישי",
	"field-tue-relative+1": "יום שלישי הבא",
	"dayPeriods-format-wide-am": "לפנה״צ",
	"dateFormatItem-MMMMEd": "E, d בMMMM",
	"field-mon-relative+0": "יום שני",
	"field-mon-relative+1": "יום שני הבא",
	"dateFormat-short": "d בMMMM y",
	"field-second": "שנייה",
	"field-sat-relative+-1": "יום שבת שעבר",
	"field-sun-relative+-1": "יום ראשון שעבר",
	"field-month-relative+0": "החודש",
	"field-month-relative+1": "החודש הבא",
	"dateFormatItem-Ed": "E ה-d",
	"field-week": "שבוע",
	"dateFormat-medium": "d בMMMM y",
	"field-year-relative+0": "השנה",
	"field-week-relative+-1": "השבוע שעבר",
	"dateFormatItem-yyyyM": "MMMM y",
	"field-year-relative+1": "השנה הבאה",
	"dateTimeFormat-short": "{1}, {0}",
	"months-format-wide-leap": "אדר ב׳",
	"dateFormatItem-GyMMM": "MMMM y G",
	"field-mon-relative+-1": "יום שני שעבר",
	"dateFormatItem-yyyy": "y G",
	"field-week-relative+0": "השבוע",
	"field-week-relative+1": "השבוע הבא"
}
//end v1.x content
);
